# tifuun-sensitivity

Sensitivity calculator for TIFUUN-type spectrometers

## Overview

`tifuun-sensitivity` is a Python package which enables to calculate observation sensitivity of TIFUUN-type spectrometers.
Currently it is mainly used to estimate the observation sensitivity of TIFUUN.

## Requirements

- **Python:** 3.11 (tested by the authors)
- **Dependencies:** See [pyproject.toml](https://github.com/tifuun/tifuun-sensitivity/blob/main/pyproject.toml)
- **Optional dependencies:** 
    - `nose2` for running the unittests

## Installation
### From PyPI
Simply run:
```shell
pip install tifuun-sensitivity
```
This will install the most recent version on PyPI.

### From source
After cloning, navigate to the directory containing this README and run:
```shell
pip install .
```

## How to use it
Please have a look at the "Basics of running tifuun-sensitivity" notebook in the `/ipynb/` folder.
